@@ -1,9 +1,17 @@
 """Base classes for the CMS admin interface."""
 
 from django.contrib import admin
+from django.contrib.auth.models import User
+from django.contrib.admin.sites import NotRegistered
+
+try:
+    from usertools.admin import UserAdmin
+except ImportError:
+    from django.contrib.auth.admin import UserAdmin
 
 from cms import externals
 from cms.models.base import SearchMetaBaseSearchAdapter, PageBaseSearchAdapter
+from cms.forms import CMSAdminPasswordChangeForm
 
 
 class PublishedBaseAdmin(admin.ModelAdmin):
@@ -90,3 +98,15 @@ class PageBaseAdmin(SearchMetaBaseAdmin):
         NAVIGATION_FIELDS,
         SearchMetaBaseAdmin.SEO_FIELDS,
     )
+
+
+class CMSUserAdmin(UserAdmin):
+    change_password_form = CMSAdminPasswordChangeForm
+    invite_confirm_form = CMSAdminPasswordChangeForm
+
+try:
+    admin.site.unregister(User)
+except NotRegistered:
+    pass
+
+admin.site.register(User, CMSUserAdmin)
