@@ -5,6 +5,7 @@ from functools import partial
 
 from django.core.files import File as DjangoFile
 from django.core.files.temp import NamedTemporaryFile
+from django.core.paginator import Paginator
 from django.conf.urls import patterns, url
 from django.contrib import admin, messages
 from django.contrib.admin.views.main import IS_POPUP_VAR
@@ -19,6 +20,7 @@ from cms import permalinks, externals
 from cms.apps.media.models import Label, File, Video
 
 import requests
+import json
 
 
 class LabelAdmin(admin.ModelAdmin):
@@ -127,7 +129,7 @@ class FileAdminBase(admin.ModelAdmin):
     # Customizations.
 
     def lookup_allowed(self, lookup, *args, **kwargs):
-        """Allows the file iregex lookup needed by TinyMCE integration."""
+        """Allows the file iregex lookup needed by Redactor integration."""
         if lookup == "file__iregex":
             return True
         return super(FileAdminBase, self).lookup_allowed(lookup, *args, **kwargs)
@@ -195,7 +197,7 @@ class FileAdminBase(admin.ModelAdmin):
         permalink = permalinks.create(obj)
         if icon == IMAGE_FILE_ICON:
             try:
-                thumbnail = get_thumbnail(obj.file, '100x66', crop='center', quality=99)
+                thumbnail = get_thumbnail(obj.file, '100x66', quality=99)
             except IOError:
                 pass
             else:
@@ -216,7 +218,7 @@ class FileAdminBase(admin.ModelAdmin):
 
     def response_add(self, request, obj, *args, **kwargs):
         """Returns the response for a successful add action."""
-        if "_tinymce" in request.GET:
+        if "_redactor" in request.GET:
             context = {"permalink": permalinks.create(obj),
                        "title": obj.title}
             return render(request, "admin/media/file/filebrowser_add_success.html", context)
@@ -237,7 +239,12 @@ class FileAdminBase(admin.ModelAdmin):
 
         new_urls = patterns(
             '',
-            url(r'^(?P<object_id>\d+)/remote/$', self.remote_view, name="media_file_remote")
+            url(r'^(?P<object_id>\d+)/remote/$', self.remote_view, name="media_file_remote"),
+
+            url(r'^redactor/upload/(?P<file_type>image|file)/$', self.redactor_upload, name="media_file_redactor_upload"),
+
+            url(r'^redactor/(?P<file_type>images|files)/$', self.redactor_data, name="media_file_redactor_data"),
+            url(r'^redactor/(?P<file_type>images|files)/(?P<page>\d+)/$', self.redactor_data, name="media_file_redactor_data"),
         )
 
         return new_urls + urls
@@ -267,6 +274,85 @@ class FileAdminBase(admin.ModelAdmin):
         ))
         return HttpResponse('{"status": "ok"}', content_type='application/json')
 
+    def redactor_data(self, request, **kwargs):
+        if not self.has_change_permission(request):
+            return HttpResponseForbidden("You do not have permission to view these files.")
+
+        file_type = kwargs.get('file_type', 'files')
+        page = kwargs.get('page', 1)
+
+        # Make sure we serve the correct data
+        if file_type == 'files':
+            file_objects = File.objects.all()
+        elif file_type == 'images':
+            file_objects = File.objects.filter(file__regex=r'(?i)\.(png|gif|jpg|jpeg)$')
+
+        # Sort objects by title
+        file_objects = file_objects.order_by('title')
+
+        # Create paginator
+        paginator = Paginator(file_objects, 15)
+
+        # Create files usable by the CMS
+        json_data = {
+            'page': page,
+            'pages': paginator.page_range,
+        }
+
+        if file_type == 'files':
+            json_data['objects'] = [
+                {'title': file_object.title, 'url': permalinks.create(file_object)}
+                for file_object in paginator.page(page)
+            ]
+        elif file_type == 'images':
+            json_data['objects'] = [
+                {'title': file_object.title, 'url': permalinks.create(file_object), 'thumbnail': get_thumbnail(file_object.file, '100x75', crop="center", quality=99).url}
+                for file_object in paginator.page(page)
+            ]
+
+        # Return files as ajax
+        return HttpResponse(json.dumps(json_data), content_type='application/json')
+
+    def redactor_upload(self, request, file_type):
+        if not self.has_change_permission(request):
+            return HttpResponseForbidden("You do not have permission to upload this file.")
+
+        if request.method != 'POST':
+            return HttpResponseNotAllowed(['POST'])
+
+        image_content_types = [
+            'image/gif',
+            'image/jpeg',
+            'image/png',
+            'image/bmp'
+        ]
+
+        try:
+
+            if file_type == 'image':
+                if request.FILES.getlist('file')[0].content_type not in image_content_types:
+                    raise Exception()
+
+            new_file = File(
+                title=request.FILES.getlist('file')[0].name,
+                file=request.FILES.getlist('file')[0]
+            )
+            new_file.save()
+
+            if file_type == 'image':
+                return HttpResponse(json.dumps({
+                    'filelink': permalinks.create(new_file)
+                }))
+            else:
+                return HttpResponse(json.dumps({
+                    'filelink': permalinks.create(new_file),
+                    'filename': request.FILES.getlist('file')[0].name,
+                }))
+
+        except:
+            return HttpResponse('')
+
+
 
 # Renaming needed to allow inheritance to take place in this class without infinite recursion.
 FileAdmin = FileAdminBase
