@@ -63,9 +63,9 @@ STATIC_URL = "/static/"
 
 # Email settings.
 
-EMAIL_HOST = ""
+EMAIL_HOST = "smtp.mandrillapp.com"
 
-EMAIL_HOST_USER = "{{ project_name }}"
+EMAIL_HOST_USER = "developers@onespacemedia.com"
 
 EMAIL_HOST_PASSWORD = ""
 
@@ -147,6 +147,7 @@ INSTALLED_APPS = (
 
     'server_management',
     'django_extensions',
+    'cachalot',
 
     'social.apps.django_app.default',
 )
@@ -164,6 +165,11 @@ STATICFILES_FINDERS = (
     'compressor.finders.CompressorFinder',
 )
 
+COMPRESS_CSS_FILTERS = [
+    'compressor.filters.css_default.CssAbsoluteFilter',
+    'compressor.filters.cssmin.CSSMinFilter'
+]
+
 # Dispatch settings.
 
 MIDDLEWARE_CLASSES = (
@@ -239,7 +245,8 @@ CACHE_MIDDLEWARE_KEY_PREFIX = "{{ project_name }}"
 
 CACHES = {
     "default": {
-        "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
+        "BACKEND": "django.core.cache.backends.memcached.MemcachedCache",
+        'LOCATION': '127.0.0.1:11211',
     }
 }
 
@@ -249,30 +256,18 @@ CACHES = {
 SECRET_KEY = "{{ secret_key }}"
 
 
-# TinyMCE settings.
-
-RICHTEXT_SETTINGS = {
-    "default": {
-        "theme": "advanced",
-        "plugins": "table, advimage, inlinepopups, paste",
-        "paste_auto_cleanup_on_paste": True,
-        "paste_remove_spans": True,
-        "paste_remove_styles": True,
-        "theme_advanced_buttons1": "code,|,formatselect,styleselect,|,bullist,numlist,table,hr,|,bold,italic,|,link,unlink,image",
-        "theme_advanced_buttons2": "",
-        "theme_advanced_buttons3": "",
-        "theme_advanced_resizing": True,
-        "theme_advanced_path": False,
-        "theme_advanced_statusbar_location": "bottom",
-        "width": "700px",
-        "height": "350px",
-        "dialog_type": "modal",
-        "theme_advanced_blockformats": "h1,h2,h3,h4,h5,h6,p",
-        "content_css": "css/screen.content.css",
-        "extended_valid_elements": "iframe[scrolling|frameborder|class|id|src|width|height|name|align],article[id|class],section[id|class]",
-        "convert_urls": False,
-        "accessibility_warnings": False,
-    }
+REDACTOR_OPTIONS = {
+    "plugins": ["table", "imagemanager", "video", "filemanager"],
+    "imageUpload": "/admin/media/file/redactor/upload/image/",
+    "fileUpload": "/admin/media/file/redactor/upload/file/",
+    "minHeight": 300,
+    "formattingAdd": [
+        {
+            "tag": "a",
+            "title": "Button",
+            "class": "button primary",
+        }
+    ]
 }
 
 
@@ -286,13 +281,28 @@ ADOBE_CREATIVE_SDK_CLIENT_SECRET = ''
 ADOBE_CREATIVE_SDK_CLIENT_ID = ''
 
 # Google Apps authentication.
+
+# SETUP:
+# 1. https://console.developers.google.com/project
+# 2. "Create project"
+# 3. APIs & auth -> Consent screen
+# 4. Select email address
+# 5. APIs & auth -> APIs
+# 6. Enable "Google+ API"
+# 7. APIs & auth -> Credentials
+# 8. Create new Client ID -> Web application
+# 9. Copy Client ID to KEY below.
+# 10. Copy Client Secret to SECRET below.
+# 11. Edit settings
+# 12. Set authorized domain
+
 AUTHENTICATION_BACKENDS = (
     'social.backends.google.GooglePlusAuth',
     'django.contrib.auth.backends.ModelBackend'
 )
 
-SOCIAL_AUTH_GOOGLE_PLUS_KEY = '607248109866-kglfuv4oh0g09e4qd0je35efmk4im762.apps.googleusercontent.com'
-SOCIAL_AUTH_GOOGLE_PLUS_SECRET = 'otU-ouuhBDop5SPetPX931Nt'
+SOCIAL_AUTH_GOOGLE_PLUS_KEY = ''
+SOCIAL_AUTH_GOOGLE_PLUS_SECRET = ''
 WHITELISTED_DOMAINS = ['onespacemedia.com']
 
 SOCIAL_AUTH_LOGIN_REDIRECT_URL = '/admin/'
